@@ -13,7 +13,7 @@ use File::Spec::Functions qw( catdir catfile );
 use constant DEBUG    => $ENV{MOJO_ASSETPACK_DEBUG}    || 0;
 use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 
-our $VERSION = '0.68';
+our $VERSION = '0.69';
 
 our $MINIFY = undef;    # internal use only!
 my $MONIKER_RE = qr{^(.+)\.(\w+)$};
@@ -39,7 +39,7 @@ sub add {
 sub fetch {
   my $self  = shift;
   my $url   = Mojo::URL->new(shift);
-  my $asset = $self->_handler($url->scheme)->asset_for($url, $self);
+  my $asset = $self->_handler($url->scheme || 'https')->asset_for($url, $self);
   return $asset if @_;    # internal
   return $asset->path;    # documented api
 }
@@ -161,7 +161,7 @@ sub _asset {
 
 sub _build_out_dir {
   my ($self, $app, $config) = @_;
-  my $out_dir;
+  my ($out_dir, $packed);
 
   if ($out_dir = $config->{out_dir}) {
     my $static_dir = Cwd::abs_path(catdir $out_dir, File::Spec->updir);
@@ -169,18 +169,13 @@ sub _build_out_dir {
   }
   if (!$out_dir) {
     for my $path (@{$app->static->paths}) {
-      my $packed = catdir $path, 'packed';
+      $packed = catdir $path, 'packed';
       if (-w $path) { $out_dir = Cwd::abs_path($packed); last }
       if (-r $packed) { $out_dir ||= Cwd::abs_path($packed) }
     }
   }
-  if (!$out_dir) {
-    die "[AssetPack] Neither readable, nor writeable 'out_dir' directory "
-      . "could be found in static paths @{$app->static->paths}. "
-      . "Maybe you forgot to pre-pack the assets? "
-      . "https://metacpan.org/pod/Mojolicious::Plugin::AssetPack::Manual::Cookbook";
-  }
 
+  $out_dir ||= $packed or die "[AssetPack] app->static->paths is not set";
   File::Path::make_path($out_dir) unless -d $out_dir;
   $self->{out_dir} = $out_dir;
 }
@@ -388,7 +383,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.68
+0.69
 
 =head1 SYNOPSIS
 
