@@ -9,7 +9,7 @@ Mojolicious::Plugin::AssetPack::Handler::Sprites - A URL handler for sprites://
 L<Mojolicious::Plugin::AssetPack::Handler::Sprites> is a module that can
 generate sprites from image files in a directory.
 
-This module require L<Imager> and L<Imager::File::PNG> to work. Below you can
+This module requires L<Imager> and L<Imager::File::PNG> to work. Below you can
 see how to install it on Debian or Ubuntu:
 
   $ apt-get install libpng12-dev
@@ -65,7 +65,7 @@ sub asset_for {
     my ($w, $h) = ($tile->getwidth, $tile->getheight);
     $cn =~ s!\.\w+$!!;
     $cn =~ s!\W!-!g;
-    $css .= ".$name.$cn { background-position: 0px -$size[1]px; width: ${w}px; height: ${h}px; }\n";
+    $css .= ".$name.$cn { background-position: 0 -$size[1]px; width: ${w}px; height: ${h}px; }\n";
     warn "[AssetPack] Adding $directory/$file to sprite $name.png $w x $h\n" if DEBUG;
     $tiled->paste(src => $tile, left => 0, top => $size[1]) or die $tiled->errstr;
     $size[1] += $h;
